@@ -13,7 +13,7 @@ def init(library):
     Unused. asks+anyio auto-detects your library.
     """
     warn(
-        'init is deprecated. asks + anyio now auto-detects'
-        ' your async library', DeprecationWarning
+        "init is deprecated. asks + anyio now auto-detects" " your async library",
+        DeprecationWarning,
     )
     pass
