@@ -75,6 +75,9 @@ class RequestProcessor:
 
         max_redirects (int): The maximum number of redirects allowed.
 
+        follow_redirects (bool): Whether to follow redirects or return raw 3xx
+            responses.
+
         persist_cookies (True or None): Passing True instantiates a
             CookieTracker object to manage the return of cookies to the server
             under the relevant domains.
@@ -104,6 +107,7 @@ class RequestProcessor:
         self.stream = None
         self.timeout = None
         self.max_redirects = 20
+        self.follow_redirects = True
         self.sock = None
         self.persist_cookies = None
         self.mimetype = None
@@ -170,7 +174,7 @@ class RequestProcessor:
                 ("Accept-Encoding", "gzip, deflate"),
                 ("Accept", "*/*"),
                 ("Content-Length", "0"),
-                ("User-Agent", "python-asks/2.4.7"),
+                ("User-Agent", "python-asks/2.4.8"),
             ]
         )
 
@@ -282,7 +286,8 @@ class RequestProcessor:
         if self.method != "HEAD":
             if self.max_redirects < 0:
                 raise TooManyRedirects
-            response_obj = await self._redirect(response_obj)
+            if self.follow_redirects:
+                response_obj = await self._redirect(response_obj)
         response_obj.history = self.history_objects
 
         return response_obj
@@ -592,7 +597,9 @@ class RequestProcessor:
                 if "chunked" in resp_data["headers"]["transfer-encoding"].lower():
                     get_body = True
             except KeyError:
-                if resp_data["headers"].get("connection", "").lower() == "close":
+                connection_close = resp_data["headers"].get("connection", "").lower() == "close"
+                http_1 = response.http_version == b"1.0"
+                if connection_close or http_1:
                     get_body = True
 
         if get_body:
