@@ -11,20 +11,23 @@ from .errors import BadStatus
 
 
 class BaseResponse:
-    '''
+    """
     A response object supporting a range of methods and attribs
     for accessing the status line, header, cookies, history and
     body of a response.
-    '''
-    def __init__(self,
-                 encoding,
-                 http_version,
-                 status_code,
-                 reason_phrase,
-                 headers,
-                 body,
-                 method,
-                 url):
+    """
+
+    def __init__(
+        self,
+        encoding,
+        http_version,
+        status_code,
+        reason_phrase,
+        headers,
+        body,
+        method,
+        url,
+    ):
         self.encoding = encoding
         self.http_version = http_version
         self.status_code = status_code
@@ -36,29 +39,51 @@ class BaseResponse:
         self.history = []
         self.cookies = []
 
+    def raise_for_status(self):
+        """
+        Raise BadStatus if one occurred.
+        """
+        if 400 <= self.status_code < 500:
+            raise BadStatus(
+                "{} Client Error: {} for url: {}".format(
+                    self.status_code, self.reason_phrase, self.url
+                ),
+                self,
+                self.status_code,
+            )
+        elif 500 <= self.status_code < 600:
+            raise BadStatus(
+                "{} Server Error: {} for url: {}".format(
+                    self.status_code, self.reason_phrase, self.url
+                ),
+                self,
+                self.status_code,
+            )
+
     def __repr__(self):
-        return '<{} {} {}>'.format(self.__class__.__name__,
-                                   self.status_code,
-                                   self.reason_phrase)
+        return "<{} {} {}>".format(
+            self.__class__.__name__, self.status_code, self.reason_phrase
+        )
 
     def _guess_encoding(self):
         try:
-            guess = self.headers['content-type'].split('=')[1]
+            guess = self.headers["content-type"].split("=")[1]
             codecs.lookup(guess)
             self.encoding = guess
         except LookupError:  # IndexError/KeyError are LookupError subclasses
             pass
 
     def _decompress(self, encoding=None):
-        content_encoding = self.headers.get('Content-Encoding', None)
+        content_encoding = self.headers.get("Content-Encoding", None)
         if content_encoding is not None:
-            decompressor = decompress(parse_content_encoding(content_encoding),
-                                      encoding)
+            decompressor = decompress(
+                parse_content_encoding(content_encoding), encoding
+            )
             r = decompressor.send(self.body)
             return r
         else:
             if encoding is not None:
-                return self.body.decode(encoding, errors='replace')
+                return self.body.decode(encoding, errors="replace")
             else:
                 return self.body
 
@@ -70,55 +95,33 @@ class BaseResponse:
 
 
 class Response(BaseResponse):
-
     def json(self, **kwargs):
-        '''
+        """
         If the response's body is valid json, we load it as a python dict
         and return it.
-        '''
+        """
         body = self._decompress(self.encoding)
         return _json.loads(body, **kwargs)
 
-    def raise_for_status(self):
-        '''
-        Raise BadStatus if one occurred.
-        '''
-        if 400 <= self.status_code < 500:
-            raise BadStatus(
-                '{} Client Error: {} for url: {}'.format(
-                    self.status_code, self.reason_phrase, self.url
-                ),
-                self,
-                self.status_code
-            )
-        elif 500 <= self.status_code < 600:
-            raise BadStatus(
-                '{} Server Error: {} for url: {}'.format(
-                    self.status_code, self.reason_phrase, self.url
-                ),
-                self,
-                self.status_code
-            )
-
     @property
     def text(self):
-        '''
+        """
         Returns the (maybe decompressed) decoded version of the body.
-        '''
+        """
         return self._decompress(self.encoding)
 
     @property
     def content(self):
-        '''
+        """
         Returns the content as-is after decompression, if any.
-        '''
+        """
         return self._decompress()
 
     @property
     def raw(self):
-        '''
+        """
         Returns the response body as received.
-        '''
+        """
         return self.body
 
 
@@ -127,7 +130,6 @@ class StreamResponse(BaseResponse):
 
 
 class StreamBody:
-
     def __init__(self, h11_connection, sock, content_encoding=None, encoding=None):
         self.h11_connection = h11_connection
         self.sock = sock
@@ -157,7 +159,9 @@ class StreamBody:
             event = self.h11_connection.next_event()
 
             if event is h11.NEED_DATA:
-                data = await timeout_manager(self.timeout, self.sock.receive_some, self.read_size)
+                data = await timeout_manager(
+                    self.timeout, self.sock.receive_some, self.read_size
+                )
                 self.h11_connection.receive_data(data)
                 continue
 
@@ -178,10 +182,11 @@ class StreamBody:
 
 
 class Cookie(SimpleNamespace):
-    '''
+    """
     A simple cookie object, for storing cookie stuff :)
     Needs to be made compatible with the API's cookies kw arg.
-    '''
+    """
+
     def __init__(self, host, data):
         self.name = None
         self.value = None
@@ -198,9 +203,9 @@ class Cookie(SimpleNamespace):
 
     def __repr__(self):
         if self.name is not None:
-            return '<Cookie {} from {}>'.format(self.name, self.host)
+            return "<Cookie {} from {}>".format(self.name, self.host)
         else:
-            return '<Cookie {} from {}>'.format(self.value, self.host)
+            return "<Cookie {} from {}>".format(self.value, self.host)
 
     def __iter__(self):
         for k, v in self.__dict__.items():
